=============
Release Notes
=============

0.4.0 (2017-08-10)
------------------

* Add ``--version`` option.
* Add Python 3.6, remove 3.3.
* Add many quality-assurance checks and additional documentation (PR `#2`_).

.. _`#2`: https://github.com/weaverba137/hpsspy/pull/2

0.3.0 (2017-01-18)
------------------

* General refresh of Python code, documentation, test suite.  However,
  no major changes to the API.
* Command-line inputs are no longer rigidly restricted to SDSS or DESI.

0.2.1 (2015-04-22)
------------------

* Fixed some setup.py errors, no code changes.

0.2.0 (2015-04-22)
------------------

* Moved configuration items to JSON files.
* Started adding support for DESI.
* Add tests to util subpackage.
* Add ``__future__`` statements.
* Clean up API documentation.
* Minor bug fixes.

0.1.0 (2015-03-25)
------------------

* Initial release.  Used to scan all SDSS data.
